==> KCsmart_2.8.0.zip: KCsmart/doc/KCS.R <==
###################################################
### chunk number 1: 
###################################################
#line 23 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
library(KCsmart)


###################################################
### chunk number 2: 
###################################################
#line 27 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
data(hsSampleData)


###################################################
### chunk number 3: 
###################################################
#line 31 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
str(hsSampleData)


###################################################
### chunk number 4: 
###################################################
#line 39 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
data(hsMirrorLocs)


###################################################
### chunk number 5: 
###################################################
#line 43 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
spm1mb <- calcSpm(hsSampleData, hsMirrorLocs)
spm4mb <- calcSpm(hsSampleData, hsMirrorLocs, sigma=4000000)


###################################################
### chunk number 6: 
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
plot(spm1mb)


###################################################
### chunk number 7: 
###################################################
#line 58 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
plot(spm1mb, chromosomes=c(1, 12, "X"), type="g")


###################################################
### chunk number 8: 
###################################################
#line 65 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
sigLevel1mb <- findSigLevelTrad(hsSampleData, spm1mb, n=10, p=0.05)


###################################################
### chunk number 9: 
###################################################
#line 72 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
plot(spm1mb, sigLevels=sigLevel1mb, type=1)


###################################################
### chunk number 10: 
###################################################
#line 80 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
plot(spm1mb, chromosomes=c(1, 12, "X"), type="g", sigLevels=sigLevel1mb)


###################################################
### chunk number 11: 
###################################################
#line 89 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
sigRegions1mb <- getSigSegments(spm1mb,sigLevel1mb)


###################################################
### chunk number 12: 
###################################################
#line 95 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
sigRegions1mb


###################################################
### chunk number 13: 
###################################################
#line 101 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
sigRegions1mb@gains[[1]]$probes


###################################################
### chunk number 14: 
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
sigLevel4mb <- findSigLevelTrad(hsSampleData, spm4mb, n=10)


###################################################
### chunk number 15: 
###################################################
#line 118 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
plotScaleSpace(list(spm1mb, spm4mb), list(sigLevel1mb, sigLevel4mb), type='g')


###################################################
### chunk number 16: 
###################################################
#line 133 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
spmc1mb <- calcSpmCollection(hsSampleData, hsMirrorLocs, cl=c(rep(0,10),rep(1,10)), sigma=1000000)


###################################################
### chunk number 17: 
###################################################
#line 139 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
spmc1mb.sig <- compareSpmCollection(spmc1mb, nperms=3, method=c("siggenes"))
spmc1mb.sig


###################################################
### chunk number 18: 
###################################################
#line 146 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
spmc1mb.sig.regions <- getSigRegionsCompKC(spmc1mb.sig)
spmc1mb.sig.regions


###################################################
### chunk number 19: 
###################################################
#line 154 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmphnMbyh/R.INSTALL3cef400b/KCsmart/inst/doc/KCS.Rnw"
plot(spmc1mb.sig, sigRegions=spmc1mb.sig.regions)

==> KCsmart_2.10.0.zip: KCsmart/doc/KCS.R <==
###################################################
### chunk number 1: 
###################################################
#line 23 "KCS.Rnw"
library(KCsmart)


###################################################
### chunk number 2: 
###################################################
#line 27 "KCS.Rnw"
data(hsSampleData)


###################################################
### chunk number 3: 
###################################################
#line 31 "KCS.Rnw"
str(hsSampleData)


###################################################
### chunk number 4: 
###################################################
#line 39 "KCS.Rnw"
data(hsMirrorLocs)


###################################################
### chunk number 5: 
###################################################
#line 43 "KCS.Rnw"
spm1mb <- calcSpm(hsSampleData, hsMirrorLocs)
spm4mb <- calcSpm(hsSampleData, hsMirrorLocs, sigma=4000000)


###################################################
### chunk number 6: 
###################################################
#line 50 "KCS.Rnw"
plot(spm1mb)


###################################################
### chunk number 7: 
###################################################
#line 57 "KCS.Rnw"
plot(spm1mb, chromosomes=c(1, 12, "X"), type="g")


###################################################
### chunk number 8: 
###################################################
#line 64 "KCS.Rnw"
sigLevel4mb <- findSigLevelTrad(hsSampleData, spm4mb, n=10, p=0.05)


###################################################
### chunk number 9: 
###################################################
#line 71 "KCS.Rnw"
plot(spm4mb, sigLevels=sigLevel4mb, type=1)


###################################################
### chunk number 10: 
###################################################
#line 79 "KCS.Rnw"
plot(spm4mb, chromosomes=c(1, 12, "X"), type="g", sigLevels=sigLevel4mb)


###################################################
### chunk number 11: 
###################################################
#line 88 "KCS.Rnw"
sigRegions4mb <- getSigSegments(spm4mb,sigLevel4mb)


###################################################
### chunk number 12: 
###################################################
#line 94 "KCS.Rnw"
sigRegions4mb


###################################################
### chunk number 13: 
###################################################
#line 100 "KCS.Rnw"
sigRegions4mb@gains[[1]]$probes


###################################################
### chunk number 14: 
###################################################
#line 110 "KCS.Rnw"
sigLevel1mb <- findSigLevelTrad(hsSampleData, spm1mb, n=10)


###################################################
### chunk number 15: 
###################################################
#line 117 "KCS.Rnw"
plotScaleSpace(list(spm1mb, spm4mb), list(sigLevel1mb, sigLevel4mb), type='g')


###################################################
### chunk number 16: 
###################################################
#line 132 "KCS.Rnw"
spmc1mb <- calcSpmCollection(hsSampleData, hsMirrorLocs, cl=c(rep(0,10),rep(1,10)), sigma=1000000)


###################################################
### chunk number 17: 
###################################################
#line 138 "KCS.Rnw"
spmc1mb.sig <- compareSpmCollection(spmc1mb, nperms=3, method=c("siggenes"))
spmc1mb.sig


###################################################
### chunk number 18: 
###################################################
#line 145 "KCS.Rnw"
spmc1mb.sig.regions <- getSigRegionsCompKC(spmc1mb.sig)
spmc1mb.sig.regions


###################################################
### chunk number 19: 
###################################################
#line 153 "KCS.Rnw"
plot(spmc1mb.sig, sigRegions=spmc1mb.sig.regions)
